[longomatch/newui: 76/104] Fix more background colors



commit f7ffa3823467adfaf6e5441d29f31bc3244d1c12
Author: Andoni Morales Alastruey <ylatuya gmail com>
Date:   Fri Aug 22 19:50:20 2014 +0200

    Fix more background colors

 .../CanvasObjects/PlayersTaggerObject.cs           |    1 +
 LongoMatch.Drawing/Widgets/CategoriesLabels.cs     |   10 +
 LongoMatch.Drawing/Widgets/Dashboard.cs            |    7 +-
 LongoMatch.Drawing/Widgets/PlaysTimeline.cs        |    9 +
 LongoMatch.Drawing/Widgets/PositionTagger.cs       |    9 +
 .../gtk-gui/LongoMatch.Gui.PlayerBin.cs            |   15 +-
 LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic       |  321 ++++++++++----------
 LongoMatch.GUI/Gui/Component/CodingWidget.cs       |    2 +-
 .../LongoMatch.Gui.Component.CodingWidget.cs       |   17 +-
 ...ongoMatch.Gui.Component.PlaysSelectionWidget.cs |   48 ++--
 LongoMatch.GUI/gtk-gui/gui.stetic                  |   43 +--
 data/theme/gtk-2.0/gtkrc                           |    5 +
 12 files changed, 258 insertions(+), 229 deletions(-)
---
diff --git a/LongoMatch.Drawing/CanvasObjects/PlayersTaggerObject.cs 
b/LongoMatch.Drawing/CanvasObjects/PlayersTaggerObject.cs
index b81a58c..b11437b 100644
--- a/LongoMatch.Drawing/CanvasObjects/PlayersTaggerObject.cs
+++ b/LongoMatch.Drawing/CanvasObjects/PlayersTaggerObject.cs
@@ -437,6 +437,7 @@ namespace LongoMatch.Drawing.CanvasObjects
                        Image.ScaleFactor ((int)width, (int)height, (int)Width, (int)Height,
                                           out scaleX, out scaleY, out offset);
                        tk.Begin ();
+                       tk.Clear (Config.Style.PaletteBackground);
                        tk.TranslateAndScale (Position + offset, new Point (scaleX, scaleY));
                        homeBench.Draw (tk, area);
                        awayBench.Draw (tk, area);
diff --git a/LongoMatch.Drawing/Widgets/CategoriesLabels.cs b/LongoMatch.Drawing/Widgets/CategoriesLabels.cs
index 4885353..b31c86e 100644
--- a/LongoMatch.Drawing/Widgets/CategoriesLabels.cs
+++ b/LongoMatch.Drawing/Widgets/CategoriesLabels.cs
@@ -96,6 +96,16 @@ namespace LongoMatch.Drawing.Widgets
                        }
                        widget.ReDraw ();
                }
+               
+               public override void Draw (IContext context, Area area)
+               {
+                       tk.Context = context;
+                       tk.Begin ();
+                       tk.Clear (Config.Style.PaletteBackground);
+                       tk.End ();
+
+                       base.Draw (context, area);
+               }
        }
 }
 
diff --git a/LongoMatch.Drawing/Widgets/Dashboard.cs b/LongoMatch.Drawing/Widgets/Dashboard.cs
index 8199454..8c1aaa9 100644
--- a/LongoMatch.Drawing/Widgets/Dashboard.cs
+++ b/LongoMatch.Drawing/Widgets/Dashboard.cs
@@ -163,9 +163,10 @@ namespace LongoMatch.Drawing.Widgets
 
                public override void Draw (IContext context, Area area)
                {
+                       tk.Context = context;
+                       tk.Begin ();
+                       tk.Clear (Config.Style.PaletteBackground);
                        if (TagMode == TagMode.Edit) {
-                               tk.Context = context;
-                               tk.Begin ();
                                tk.TranslateAndScale (translation, new Point (scaleX, scaleY));
                                /* Draw grid */
                                tk.LineWidth = 1;
@@ -179,8 +180,8 @@ namespace LongoMatch.Drawing.Widgets
                                for (int i = 0; i < templateWidth; i += Constants.CATEGORY_TPL_GRID) {
                                        tk.DrawLine (new Point (i, 0), new Point (i, templateHeight));
                                }
-                               tk.End ();
                        }
+                       tk.End ();
                        
                        base.Draw (context, area);
                }
diff --git a/LongoMatch.Drawing/Widgets/PlaysTimeline.cs b/LongoMatch.Drawing/Widgets/PlaysTimeline.cs
index 3805afb..289c750 100644
--- a/LongoMatch.Drawing/Widgets/PlaysTimeline.cs
+++ b/LongoMatch.Drawing/Widgets/PlaysTimeline.cs
@@ -200,6 +200,15 @@ namespace LongoMatch.Drawing.Widgets
                        }
                        Config.EventsBroker.EmitTimeNodeChanged (play, moveTime);
                }
+               
+               public override void Draw (IContext context, Area area)
+               {
+                       tk.Context = context;
+                       tk.Begin ();
+                       tk.Clear (Config.Style.PaletteBackground);
+                       tk.End ();
+                       base.Draw (context, area);
+               }
        }
 }
 
diff --git a/LongoMatch.Drawing/Widgets/PositionTagger.cs b/LongoMatch.Drawing/Widgets/PositionTagger.cs
index 4a64393..fc094cd 100644
--- a/LongoMatch.Drawing/Widgets/PositionTagger.cs
+++ b/LongoMatch.Drawing/Widgets/PositionTagger.cs
@@ -130,6 +130,15 @@ namespace LongoMatch.Drawing.Widgets
                                ShowMenuEvent (plays);
                        }
                }
+               
+               public override void Draw (IContext context, Area area)
+               {
+                       tk.Context = context;
+                       tk.Begin ();
+                       tk.Clear (Config.Style.PaletteBackground);
+                       tk.End ();
+                       base.Draw (context, area);
+               }
        }
 }
 
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs 
b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
index 606c82f..9e7b08b 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/LongoMatch.Gui.PlayerBin.cs
@@ -13,6 +13,7 @@ namespace LongoMatch.Gui
                private global::Gtk.DrawingArea blackboarddrawingarea;
                private global::Gtk.VBox vbox5;
                private global::Gtk.VScale vscale1;
+               private global::Gtk.EventBox lightbackgroundeventbox;
                private global::Gtk.HBox controlsbox;
                private global::Gtk.HBox buttonsbox;
                private global::Gtk.Button closebutton;
@@ -110,6 +111,9 @@ namespace LongoMatch.Gui
                        global::Gtk.Box.BoxChild w8 = ((global::Gtk.Box.BoxChild)(this.vbox3 [this.mainbox]));
                        w8.Position = 0;
                        // Container child vbox3.Gtk.Box+BoxChild
+                       this.lightbackgroundeventbox = new global::Gtk.EventBox ();
+                       this.lightbackgroundeventbox.Name = "lightbackgroundeventbox";
+                       // Container child lightbackgroundeventbox.Gtk.Container+ContainerChild
                        this.controlsbox = new global::Gtk.HBox ();
                        this.controlsbox.Name = "controlsbox";
                        this.controlsbox.Spacing = 6;
@@ -376,11 +380,12 @@ namespace LongoMatch.Gui
                        w87.Position = 6;
                        w87.Expand = false;
                        w87.Fill = false;
-                       this.vbox3.Add (this.controlsbox);
-                       global::Gtk.Box.BoxChild w88 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.controlsbox]));
-                       w88.Position = 1;
-                       w88.Expand = false;
-                       w88.Fill = false;
+                       this.lightbackgroundeventbox.Add (this.controlsbox);
+                       this.vbox3.Add (this.lightbackgroundeventbox);
+                       global::Gtk.Box.BoxChild w89 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.lightbackgroundeventbox]));
+                       w89.Position = 1;
+                       w89.Expand = false;
+                       w89.Fill = false;
                        this.Add (this.vbox3);
                        if ((this.Child != null)) {
                                this.Child.ShowAll ();
diff --git a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
index d458f93..ee9ccbd 100644
--- a/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI.Multimedia/gtk-gui/gui.stetic
@@ -175,55 +175,172 @@
           </packing>
         </child>
         <child>
-          <widget class="Gtk.HBox" id="controlsbox">
+          <widget class="Gtk.EventBox" id="lightbackgroundeventbox">
             <property name="MemberName" />
-            <property name="Visible">False</property>
-            <property name="Spacing">6</property>
             <child>
-              <widget class="Gtk.HBox" id="buttonsbox">
+              <widget class="Gtk.HBox" id="controlsbox">
                 <property name="MemberName" />
-                <property name="Homogeneous">True</property>
+                <property name="Visible">False</property>
+                <property name="Spacing">6</property>
                 <child>
-                  <widget class="Gtk.Button" id="closebutton">
+                  <widget class="Gtk.HBox" id="buttonsbox">
                     <property name="MemberName" />
-                    <property name="Visible">False</property>
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:longomatch-control-back Button</property>
-                    <property name="Label" translatable="yes" />
-                    <property name="UseUnderline">True</property>
-                    <property name="Relief">None</property>
+                    <property name="Homogeneous">True</property>
+                    <child>
+                      <widget class="Gtk.Button" id="closebutton">
+                        <property name="MemberName" />
+                        <property name="Visible">False</property>
+                        <property name="Type">TextAndIcon</property>
+                        <property name="Icon">stock:longomatch-control-back Button</property>
+                        <property name="Label" translatable="yes" />
+                        <property name="UseUnderline">True</property>
+                        <property name="Relief">None</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">0</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
+                    <child>
+                      <widget class="Gtk.Button" id="drawbutton">
+                        <property name="MemberName" />
+                        <property name="Type">TextAndIcon</property>
+                        <property name="Icon">stock:longomatch-control-draw Button</property>
+                        <property name="Label" translatable="yes" />
+                        <property name="UseUnderline">True</property>
+                        <property name="Relief">None</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">1</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
+                    <child>
+                      <widget class="Gtk.Button" id="playbutton">
+                        <property name="MemberName" />
+                        <property name="Type">TextAndIcon</property>
+                        <property name="Icon">stock:longomatch-control-play Button</property>
+                        <property name="Label" translatable="yes" />
+                        <property name="UseUnderline">True</property>
+                        <property name="Relief">None</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">2</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
+                    <child>
+                      <widget class="Gtk.Button" id="pausebutton">
+                        <property name="MemberName" />
+                        <property name="Type">TextAndIcon</property>
+                        <property name="Icon">stock:longomatch-control-pause Button</property>
+                        <property name="Label" translatable="yes" />
+                        <property name="UseUnderline">True</property>
+                        <property name="Relief">None</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">3</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
+                    <child>
+                      <widget class="Gtk.Button" id="prevbutton">
+                        <property name="MemberName" />
+                        <property name="Visible">False</property>
+                        <property name="Type">TextAndIcon</property>
+                        <property name="Icon">stock:longomatch-control-rw Button</property>
+                        <property name="Label" translatable="yes" />
+                        <property name="UseUnderline">True</property>
+                        <property name="Relief">None</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">4</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
+                    <child>
+                      <widget class="Gtk.Button" id="nextbutton">
+                        <property name="MemberName" />
+                        <property name="Visible">False</property>
+                        <property name="Sensitive">False</property>
+                        <property name="Type">TextAndIcon</property>
+                        <property name="Icon">stock:longomatch-control-ff Button</property>
+                        <property name="Label" translatable="yes" />
+                        <property name="UseUnderline">True</property>
+                        <property name="Relief">None</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">5</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
                   </widget>
                   <packing>
                     <property name="Position">0</property>
-                    <property name="AutoSize">True</property>
+                    <property name="AutoSize">False</property>
                     <property name="Expand">False</property>
                     <property name="Fill">False</property>
                   </packing>
                 </child>
                 <child>
-                  <widget class="Gtk.Button" id="drawbutton">
+                  <widget class="Gtk.HBox" id="hbox1">
                     <property name="MemberName" />
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:longomatch-control-draw Button</property>
-                    <property name="Label" translatable="yes" />
-                    <property name="UseUnderline">True</property>
-                    <property name="Relief">None</property>
+                    <property name="Spacing">6</property>
+                    <child>
+                      <widget class="Gtk.Label" id="jumplabel">
+                        <property name="MemberName" />
+                        <property name="LabelProp" translatable="yes">Jump (s):</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">0</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
+                    <child>
+                      <widget class="Gtk.SpinButton" id="jumpspinbutton">
+                        <property name="MemberName" />
+                        <property name="Tooltip" translatable="yes">Jump in seconds. Hold the Shift key with 
the direction keys to activate it.</property>
+                        <property name="Lower">1</property>
+                        <property name="Upper">100</property>
+                        <property name="PageIncrement">10</property>
+                        <property name="StepIncrement">1</property>
+                        <property name="ClimbRate">1</property>
+                        <property name="Numeric">True</property>
+                        <property name="Value">10</property>
+                      </widget>
+                      <packing>
+                        <property name="Position">1</property>
+                        <property name="AutoSize">True</property>
+                        <property name="Expand">False</property>
+                        <property name="Fill">False</property>
+                      </packing>
+                    </child>
                   </widget>
                   <packing>
                     <property name="Position">1</property>
-                    <property name="AutoSize">True</property>
+                    <property name="AutoSize">False</property>
                     <property name="Expand">False</property>
                     <property name="Fill">False</property>
                   </packing>
                 </child>
                 <child>
-                  <widget class="Gtk.Button" id="playbutton">
+                  <widget class="Gtk.Label" id="tlabel">
                     <property name="MemberName" />
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:longomatch-control-play Button</property>
-                    <property name="Label" translatable="yes" />
-                    <property name="UseUnderline">True</property>
-                    <property name="Relief">None</property>
+                    <property name="LabelProp" translatable="yes">Time:</property>
                   </widget>
                   <packing>
                     <property name="Position">2</property>
@@ -233,45 +350,37 @@
                   </packing>
                 </child>
                 <child>
-                  <widget class="Gtk.Button" id="pausebutton">
+                  <widget class="Gtk.HScale" id="timescale">
                     <property name="MemberName" />
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:longomatch-control-pause Button</property>
-                    <property name="Label" translatable="yes" />
-                    <property name="UseUnderline">True</property>
-                    <property name="Relief">None</property>
+                    <property name="UpdatePolicy">Discontinuous</property>
+                    <property name="Upper">1</property>
+                    <property name="PageIncrement">1</property>
+                    <property name="StepIncrement">1</property>
+                    <property name="Value">1</property>
+                    <property name="DrawValue">False</property>
+                    <property name="Digits">0</property>
+                    <property name="ValuePos">Top</property>
                   </widget>
                   <packing>
                     <property name="Position">3</property>
                     <property name="AutoSize">True</property>
-                    <property name="Expand">False</property>
-                    <property name="Fill">False</property>
                   </packing>
                 </child>
                 <child>
-                  <widget class="Gtk.Button" id="prevbutton">
+                  <widget class="Gtk.Label" id="timelabel">
                     <property name="MemberName" />
-                    <property name="Visible">False</property>
-                    <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:longomatch-control-rw Button</property>
-                    <property name="Label" translatable="yes" />
-                    <property name="UseUnderline">True</property>
-                    <property name="Relief">None</property>
                   </widget>
                   <packing>
                     <property name="Position">4</property>
-                    <property name="AutoSize">True</property>
+                    <property name="AutoSize">False</property>
                     <property name="Expand">False</property>
-                    <property name="Fill">False</property>
                   </packing>
                 </child>
                 <child>
-                  <widget class="Gtk.Button" id="nextbutton">
+                  <widget class="Gtk.Button" id="volumebutton">
                     <property name="MemberName" />
-                    <property name="Visible">False</property>
-                    <property name="Sensitive">False</property>
                     <property name="Type">TextAndIcon</property>
-                    <property name="Icon">stock:longomatch-control-ff Button</property>
+                    <property name="Icon">stock:longomatch-control-volume-hi Button</property>
                     <property name="Label" translatable="yes" />
                     <property name="UseUnderline">True</property>
                     <property name="Relief">None</property>
@@ -283,127 +392,23 @@
                     <property name="Fill">False</property>
                   </packing>
                 </child>
-              </widget>
-              <packing>
-                <property name="Position">0</property>
-                <property name="AutoSize">False</property>
-                <property name="Expand">False</property>
-                <property name="Fill">False</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.HBox" id="hbox1">
-                <property name="MemberName" />
-                <property name="Spacing">6</property>
                 <child>
-                  <widget class="Gtk.Label" id="jumplabel">
+                  <widget class="Gtk.Button" id="detachbutton">
                     <property name="MemberName" />
-                    <property name="LabelProp" translatable="yes">Jump (s):</property>
-                  </widget>
-                  <packing>
-                    <property name="Position">0</property>
-                    <property name="AutoSize">True</property>
-                    <property name="Expand">False</property>
-                    <property name="Fill">False</property>
-                  </packing>
-                </child>
-                <child>
-                  <widget class="Gtk.SpinButton" id="jumpspinbutton">
-                    <property name="MemberName" />
-                    <property name="Tooltip" translatable="yes">Jump in seconds. Hold the Shift key with the 
direction keys to activate it.</property>
-                    <property name="Lower">1</property>
-                    <property name="Upper">100</property>
-                    <property name="PageIncrement">10</property>
-                    <property name="StepIncrement">1</property>
-                    <property name="ClimbRate">1</property>
-                    <property name="Numeric">True</property>
-                    <property name="Value">10</property>
+                    <property name="Type">TextAndIcon</property>
+                    <property name="Icon">stock:longomatch-control-detach Button</property>
+                    <property name="Label" translatable="yes" />
+                    <property name="UseUnderline">True</property>
+                    <property name="Relief">None</property>
                   </widget>
                   <packing>
-                    <property name="Position">1</property>
+                    <property name="Position">6</property>
                     <property name="AutoSize">True</property>
                     <property name="Expand">False</property>
                     <property name="Fill">False</property>
                   </packing>
                 </child>
               </widget>
-              <packing>
-                <property name="Position">1</property>
-                <property name="AutoSize">False</property>
-                <property name="Expand">False</property>
-                <property name="Fill">False</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.Label" id="tlabel">
-                <property name="MemberName" />
-                <property name="LabelProp" translatable="yes">Time:</property>
-              </widget>
-              <packing>
-                <property name="Position">2</property>
-                <property name="AutoSize">True</property>
-                <property name="Expand">False</property>
-                <property name="Fill">False</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.HScale" id="timescale">
-                <property name="MemberName" />
-                <property name="UpdatePolicy">Discontinuous</property>
-                <property name="Upper">1</property>
-                <property name="PageIncrement">1</property>
-                <property name="StepIncrement">1</property>
-                <property name="Value">1</property>
-                <property name="DrawValue">False</property>
-                <property name="Digits">0</property>
-                <property name="ValuePos">Top</property>
-              </widget>
-              <packing>
-                <property name="Position">3</property>
-                <property name="AutoSize">True</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.Label" id="timelabel">
-                <property name="MemberName" />
-              </widget>
-              <packing>
-                <property name="Position">4</property>
-                <property name="AutoSize">False</property>
-                <property name="Expand">False</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.Button" id="volumebutton">
-                <property name="MemberName" />
-                <property name="Type">TextAndIcon</property>
-                <property name="Icon">stock:longomatch-control-volume-hi Button</property>
-                <property name="Label" translatable="yes" />
-                <property name="UseUnderline">True</property>
-                <property name="Relief">None</property>
-              </widget>
-              <packing>
-                <property name="Position">5</property>
-                <property name="AutoSize">True</property>
-                <property name="Expand">False</property>
-                <property name="Fill">False</property>
-              </packing>
-            </child>
-            <child>
-              <widget class="Gtk.Button" id="detachbutton">
-                <property name="MemberName" />
-                <property name="Type">TextAndIcon</property>
-                <property name="Icon">stock:longomatch-control-detach Button</property>
-                <property name="Label" translatable="yes" />
-                <property name="UseUnderline">True</property>
-                <property name="Relief">None</property>
-              </widget>
-              <packing>
-                <property name="Position">6</property>
-                <property name="AutoSize">True</property>
-                <property name="Expand">False</property>
-                <property name="Fill">False</property>
-              </packing>
             </child>
           </widget>
           <packing>
diff --git a/LongoMatch.GUI/Gui/Component/CodingWidget.cs b/LongoMatch.GUI/Gui/Component/CodingWidget.cs
index 9e626d3..8d4b551 100644
--- a/LongoMatch.GUI/Gui/Component/CodingWidget.cs
+++ b/LongoMatch.GUI/Gui/Component/CodingWidget.cs
@@ -68,7 +68,7 @@ namespace LongoMatch.Gui.Component
                        
                        Config.EventsBroker.Tick += HandleTick;
                        Config.EventsBroker.PlaySelected += HandlePlaySelected;
-                       LongoMatch.Gui.Helpers.Misc.DisableFocus (vbox);
+                       LongoMatch.Gui.Helpers.Misc.DisableFocus (this);
                        
                        buttonswidget.Mode = TagMode.Free;
                        buttonswidget.FitMode = FitMode.Fit;
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs
index 9091648..a8d0c6e 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.PlaysSelectionWidget.cs
@@ -4,7 +4,7 @@ namespace LongoMatch.Gui.Component
 {
        public partial class PlaysSelectionWidget
        {
-               private global::Gtk.HBox hbox1;
+               private global::Gtk.EventBox lightbackgroundeventbox;
                private global::Gtk.Notebook notebook2;
                private global::Gtk.Notebook notebook1;
                private global::LongoMatch.Gui.Component.PlaysListTreeWidget playsList;
@@ -16,7 +16,7 @@ namespace LongoMatch.Gui.Component
                private global::Gtk.Label label1;
                private global::LongoMatch.Gui.Component.PlayListWidget playlistwidget;
                private global::Gtk.Label label3;
-               private global::Gtk.VBox vbox2;
+               private global::Gtk.VBox vbox3;
                private global::Gtk.Notebook filtersnotebook;
                private global::Gtk.ToggleButton catfiltersbutton;
                private global::Gtk.ToggleButton playersfiltersbutton;
@@ -29,10 +29,9 @@ namespace LongoMatch.Gui.Component
                        global::Stetic.BinContainer.Attach (this);
                        this.Name = "LongoMatch.Gui.Component.PlaysSelectionWidget";
                        // Container child 
LongoMatch.Gui.Component.PlaysSelectionWidget.Gtk.Container+ContainerChild
-                       this.hbox1 = new global::Gtk.HBox ();
-                       this.hbox1.Name = "hbox1";
-                       this.hbox1.Spacing = 6;
-                       // Container child hbox1.Gtk.Box+BoxChild
+                       this.lightbackgroundeventbox = new global::Gtk.EventBox ();
+                       this.lightbackgroundeventbox.Name = "lightbackgroundeventbox";
+                       // Container child lightbackgroundeventbox.Gtk.Container+ContainerChild
                        this.notebook2 = new global::Gtk.Notebook ();
                        this.notebook2.CanFocus = true;
                        this.notebook2.Name = "notebook2";
@@ -41,7 +40,6 @@ namespace LongoMatch.Gui.Component
                        // Container child notebook2.Gtk.Notebook+NotebookChild
                        this.notebook1 = new global::Gtk.Notebook ();
                        this.notebook1.CanFocus = true;
-                       this.notebook1.Name = "notebook1";
                        this.notebook1.CurrentPage = 2;
                        this.notebook1.TabPos = ((global::Gtk.PositionType)(3));
                        // Container child notebook1.Gtk.Notebook+NotebookChild
@@ -104,19 +102,19 @@ namespace LongoMatch.Gui.Component
                        this.notebook2.SetTabLabel (this.playlistwidget, this.label3);
                        this.label3.ShowAll ();
                        // Container child notebook2.Gtk.Notebook+NotebookChild
-                       this.vbox2 = new global::Gtk.VBox ();
-                       this.vbox2.Name = "vbox2";
-                       this.vbox2.Spacing = 6;
-                       // Container child vbox2.Gtk.Box+BoxChild
+                       this.vbox3 = new global::Gtk.VBox ();
+                       this.vbox3.Name = "vbox3";
+                       this.vbox3.Spacing = 6;
+                       // Container child vbox3.Gtk.Box+BoxChild
                        this.filtersnotebook = new global::Gtk.Notebook ();
                        this.filtersnotebook.CanFocus = true;
                        this.filtersnotebook.Name = "filtersnotebook";
                        this.filtersnotebook.CurrentPage = 0;
                        this.filtersnotebook.TabPos = ((global::Gtk.PositionType)(3));
-                       this.vbox2.Add (this.filtersnotebook);
-                       global::Gtk.Box.BoxChild w6 = ((global::Gtk.Box.BoxChild)(this.vbox2 
[this.filtersnotebook]));
+                       this.vbox3.Add (this.filtersnotebook);
+                       global::Gtk.Box.BoxChild w6 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.filtersnotebook]));
                        w6.Position = 0;
-                       // Container child vbox2.Gtk.Box+BoxChild
+                       // Container child vbox3.Gtk.Box+BoxChild
                        this.catfiltersbutton = new global::Gtk.ToggleButton ();
                        this.catfiltersbutton.CanFocus = true;
                        this.catfiltersbutton.Name = "catfiltersbutton";
@@ -137,12 +135,12 @@ namespace LongoMatch.Gui.Component
                        w8.Add (w11);
                        w7.Add (w8);
                        this.catfiltersbutton.Add (w7);
-                       this.vbox2.Add (this.catfiltersbutton);
-                       global::Gtk.Box.BoxChild w15 = ((global::Gtk.Box.BoxChild)(this.vbox2 
[this.catfiltersbutton]));
+                       this.vbox3.Add (this.catfiltersbutton);
+                       global::Gtk.Box.BoxChild w15 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.catfiltersbutton]));
                        w15.Position = 1;
                        w15.Expand = false;
                        w15.Fill = false;
-                       // Container child vbox2.Gtk.Box+BoxChild
+                       // Container child vbox3.Gtk.Box+BoxChild
                        this.playersfiltersbutton = new global::Gtk.ToggleButton ();
                        this.playersfiltersbutton.CanFocus = true;
                        this.playersfiltersbutton.Name = "playersfiltersbutton";
@@ -163,25 +161,23 @@ namespace LongoMatch.Gui.Component
                        w17.Add (w20);
                        w16.Add (w17);
                        this.playersfiltersbutton.Add (w16);
-                       this.vbox2.Add (this.playersfiltersbutton);
-                       global::Gtk.Box.BoxChild w24 = ((global::Gtk.Box.BoxChild)(this.vbox2 
[this.playersfiltersbutton]));
+                       this.vbox3.Add (this.playersfiltersbutton);
+                       global::Gtk.Box.BoxChild w24 = ((global::Gtk.Box.BoxChild)(this.vbox3 
[this.playersfiltersbutton]));
                        w24.Position = 2;
                        w24.Expand = false;
                        w24.Fill = false;
-                       this.notebook2.Add (this.vbox2);
-                       global::Gtk.Notebook.NotebookChild w25 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook2 [this.vbox2]));
+                       this.notebook2.Add (this.vbox3);
+                       global::Gtk.Notebook.NotebookChild w25 = 
((global::Gtk.Notebook.NotebookChild)(this.notebook2 [this.vbox3]));
                        w25.Position = 2;
                        // Notebook tab
                        this.label2 = new global::Gtk.Label ();
                        this.label2.Name = "label2";
                        this.label2.LabelProp = global::Mono.Unix.Catalog.GetString ("  Filters  ");
                        this.label2.Angle = 90;
-                       this.notebook2.SetTabLabel (this.vbox2, this.label2);
+                       this.notebook2.SetTabLabel (this.vbox3, this.label2);
                        this.label2.ShowAll ();
-                       this.hbox1.Add (this.notebook2);
-                       global::Gtk.Box.BoxChild w26 = ((global::Gtk.Box.BoxChild)(this.hbox1 
[this.notebook2]));
-                       w26.Position = 0;
-                       this.Add (this.hbox1);
+                       this.lightbackgroundeventbox.Add (this.notebook2);
+                       this.Add (this.lightbackgroundeventbox);
                        if ((this.Child != null)) {
                                this.Child.ShowAll ();
                        }
diff --git a/LongoMatch.GUI/gtk-gui/gui.stetic b/LongoMatch.GUI/gtk-gui/gui.stetic
index bcb7dde..f254238 100644
--- a/LongoMatch.GUI/gtk-gui/gui.stetic
+++ b/LongoMatch.GUI/gtk-gui/gui.stetic
@@ -4052,9 +4052,8 @@ You can continue with the current capture, cancel it or save your project.
     <property name="MemberName" />
     <property name="Visible">False</property>
     <child>
-      <widget class="Gtk.HBox" id="hbox1">
+      <widget class="Gtk.EventBox" id="lightbackgroundeventbox">
         <property name="MemberName" />
-        <property name="Spacing">6</property>
         <child>
           <widget class="Gtk.Notebook" id="notebook2">
             <property name="MemberName" />
@@ -4150,7 +4149,7 @@ You can continue with the current capture, cancel it or save your project.
               </packing>
             </child>
             <child>
-              <widget class="Gtk.VBox" id="vbox2">
+              <widget class="Gtk.VBox" id="vbox3">
                 <property name="MemberName" />
                 <property name="Spacing">6</property>
                 <child>
@@ -4221,10 +4220,6 @@ You can continue with the current capture, cancel it or save your project.
               </packing>
             </child>
           </widget>
-          <packing>
-            <property name="Position">0</property>
-            <property name="AutoSize">True</property>
-          </packing>
         </child>
       </widget>
     </child>
@@ -6512,6 +6507,7 @@ You can continue with the current capture, cancel it or save your project.
                         <property name="MemberName" />
                         <property name="CanFocus">True</property>
                         <property name="Label" translatable="yes">New project using a video file</property>
+                        <property name="Active">True</property>
                         <property name="DrawIndicator">True</property>
                         <property name="HasLabel">True</property>
                         <property name="UseUnderline">True</property>
@@ -9937,7 +9933,18 @@ You can continue with the current capture, cancel it or save your project.
       </widget>
     </child>
   </widget>
-  <widget class="Gtk.Bin" id="LongoMatch.Gui.Component.CodingWidget" design-size="1305 494">
+  <widget class="Gtk.Bin" id="LongoMatch.Gui.Component.CodingWidget" design-size="1341 494">
+    <action-group name="Timeline">
+      <action id="positionMode">
+        <property name="Type">Radio</property>
+        <property name="Label" translatable="yes" />
+        <property name="StockId">gtk-justify-fill</property>
+        <property name="DrawAsRadio">False</property>
+        <property name="Active">False</property>
+        <property name="Value">0</property>
+        <property name="Group">codingmode</property>
+      </action>
+    </action-group>
     <action-group name="Default">
       <action id="timelineMode">
         <property name="Type">Radio</property>
@@ -9974,28 +9981,16 @@ You can continue with the current capture, cancel it or save your project.
         <property name="Group">codingmode</property>
       </action>
     </action-group>
-    <action-group name="Timeline">
-      <action id="positionMode">
-        <property name="Type">Radio</property>
-        <property name="Label" translatable="yes" />
-        <property name="StockId">gtk-justify-fill</property>
-        <property name="DrawAsRadio">False</property>
-        <property name="Active">False</property>
-        <property name="Value">0</property>
-        <property name="Group">codingmode</property>
-      </action>
-    </action-group>
     <property name="MemberName" />
     <property name="Visible">False</property>
     <child>
-      <widget class="Gtk.VBox" id="vbox">
+      <widget class="Gtk.EventBox" id="lightbackgroundeventbox">
         <property name="MemberName" />
-        <property name="Spacing">6</property>
         <child>
           <widget class="Gtk.Notebook" id="notebook">
             <property name="MemberName" />
             <property name="CanFocus">True</property>
-            <property name="CurrentPage">0</property>
+            <property name="CurrentPage">1</property>
             <property name="TabPos">Left</property>
             <property name="ShowBorder">False</property>
             <child>
@@ -10076,10 +10071,6 @@ You can continue with the current capture, cancel it or save your project.
               </packing>
             </child>
           </widget>
-          <packing>
-            <property name="Position">0</property>
-            <property name="AutoSize">True</property>
-          </packing>
         </child>
       </widget>
     </child>
diff --git a/data/theme/gtk-2.0/gtkrc b/data/theme/gtk-2.0/gtkrc
index dbd6258..fc6470e 100644
--- a/data/theme/gtk-2.0/gtkrc
+++ b/data/theme/gtk-2.0/gtkrc
@@ -129,6 +129,10 @@ style "longomatch-editor-treeview" {
   #GtkTreeView::even_row_color     = "#828282"
 }
 
+style "longomatch-light-background" {
+  bg[NORMAL]           = @bg_light_color
+}
+
 style "longomatch-menubar" {
   bg[NORMAL]           = @bg_light_color
 }
@@ -296,3 +300,4 @@ widget "*mediafilechooser*entry*" style "longomatch-filechooser-entry"
 widget "*datepicker*button*" style "longomatch-filechooser-button"
 widget "*datepicker*entry*" style "longomatch-filechooser-entry"
 widget "*mediafilechooser*button*" style "longomatch-filechooser-button"
+widget "*lightbackgroundeventbox*" style "longomatch-light-background"



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs 
b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs
index 367ad41..0d295f5 100644
--- a/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs
+++ b/LongoMatch.GUI/gtk-gui/LongoMatch.Gui.Component.CodingWidget.cs
@@ -10,7 +10,7 @@ namespace LongoMatch.Gui.Component
                private global::Gtk.RadioAction autoTaggingMode;
                private global::Gtk.Action zoomFitAction;
                private global::Gtk.RadioAction convertAction;
-               private global::Gtk.VBox vbox;
+               private global::Gtk.EventBox lightbackgroundeventbox;
                private global::Gtk.Notebook notebook;
                private global::Gtk.HPaned dashboardhpaned;
                private global::Gtk.DrawingArea teamsdrawingarea;
@@ -48,14 +48,13 @@ namespace LongoMatch.Gui.Component
                        this.UIManager.InsertActionGroup (w3, 1);
                        this.Name = "LongoMatch.Gui.Component.CodingWidget";
                        // Container child LongoMatch.Gui.Component.CodingWidget.Gtk.Container+ContainerChild
-                       this.vbox = new global::Gtk.VBox ();
-                       this.vbox.Name = "vbox";
-                       this.vbox.Spacing = 6;
-                       // Container child vbox.Gtk.Box+BoxChild
+                       this.lightbackgroundeventbox = new global::Gtk.EventBox ();
+                       this.lightbackgroundeventbox.Name = "lightbackgroundeventbox";
+                       // Container child lightbackgroundeventbox.Gtk.Container+ContainerChild
                        this.notebook = new global::Gtk.Notebook ();
                        this.notebook.CanFocus = true;
                        this.notebook.Name = "notebook";
-                       this.notebook.CurrentPage = 0;
+                       this.notebook.CurrentPage = 1;
                        this.notebook.TabPos = ((global::Gtk.PositionType)(0));
                        this.notebook.ShowBorder = false;
                        // Container child notebook.Gtk.Notebook+NotebookChild
@@ -115,10 +114,8 @@ namespace LongoMatch.Gui.Component
                        this.label5.LabelProp = global::Mono.Unix.Catalog.GetString ("page3");
                        this.notebook.SetTabLabel (this.playspositionviewer1, this.label5);
                        this.label5.ShowAll ();
-                       this.vbox.Add (this.notebook);
-                       global::Gtk.Box.BoxChild w10 = ((global::Gtk.Box.BoxChild)(this.vbox 
[this.notebook]));
-                       w10.Position = 0;
-                       this.Add (this.vbox);
+                       this.lightbackgroundeventbox.Add (this.notebook);
+                       this.Add (this.lightbackgroundeventbox);
                        if ((this.Child != null)) {
                                this.Child.ShowAll ();
                        }